@@ -13,7 +13,7 @@ def launch_ssh(token, password=""):
   #Download ngrok
   run_command("wget -q -nc https://bin.equinox.io/c/4VmDzA7iaHb/ngrok-stable-linux-amd64.zip")
   run_command("unzip -qq -n ngrok-stable-linux-amd64.zip")
-  run_command("apt-get install -qq -o=Dpkg::Use-Pty=0 openssh-server pwgen")
+  run_command("apt-get -qq install -o=Dpkg::Use-Pty=0 openssh-server pwgen")
   run_with_pipe("echo root:{} | sudo chpasswd".format(password))
   run_command("mkdir -p /var/run/sshd")
   os.system("echo 'PermitRootLogin yes' >> /etc/ssh/sshd_config")
@@ -29,9 +29,6 @@ def launch_ssh(token, password=""):
   Popen(shlex.split('./ngrok tcp --authtoken {} 22'.format(token)), stdout=PIPE,stderr=PIPE,stdin=PIPE)
   time.sleep(4)
 
-  #Print root password
-  print("Root password: {}".format(password))
-
   #Get public address
   info = run_with_pipe('''curl http://localhost:4040/api/tunnels | python3 -c "import sys, json; print(json.load(sys.stdin)['tunnels'][0]['public_url'])"''')
   
